package com.yidianling.muse.activity

import android.media.MediaPlayer
import android.os.Bundle
import android.widget.SeekBar
import com.alibaba.android.arouter.facade.annotation.Route
import com.bumptech.glide.Glide
import com.ydl.media.view.PlayerFloatHelper
import com.ydl.ydlcommon.base.BaseActivity
import com.ydl.ydlcommon.bean.StatusBarOptions
import com.ydl.ydlcommon.utils.LogUtil
import com.ydl.ydlcommon.utils.StatusBarUtils.Companion.setTransparentForImageView
import com.ydl.ydlcommon.utils.StatusBarUtils.Companion.statusBarLightMode
import com.ydl.ydlcommon.utils.remind.ToastHelper
import com.yidianling.muse.R
import com.yidianling.muse.helper.MediaPlayerManager
import com.yidianling.muse.utils.MediaPlayerTimeUtil
import com.yidianling.muse.widget.QuitMeditationDialog
import com.yidianling.muse.widget.ShareMeditationDialog
import kotlinx.android.synthetic.main.activity_play_meditation.*
import kotlinx.android.synthetic.main.exo_player_control_view.*
import java.util.*


@Route(path = "/muse/play")
class PlayMeditationActivity : BaseActivity() {

    private var bgUrl =
        "https://gimg2.baidu.com/image_search/src=http%3A%2F%2Fcuimianxinli.com%2Fupload%2F2016-07%2F16072613412794.jpg&refer=http%3A%2F%2Fcuimianxinli.com&app=2002&size=f9999,10000&q=a80&n=0&g=0n&fmt=auto?sec=1654150276&t=393628420414c371b4b00540943cf0c7"

    private val path =
        "http://file.kuyinyun.com/group1/M00/90/B7/rBBGdFPXJNeAM-nhABeMElAM6bY151.mp3"

    private var collected = false
    private var isPlaying = false

    private var shareDialog: ShareMeditationDialog? = null
    private var quitDialog: QuitMeditationDialog? = null

    private var mTimer = Timer()
    private var mMediaPlayer:MediaPlayer?=null

    private var duration = 0

    private var isSeekbarChanging = false

    override fun onCreate(savedInstanceState: Bundle?) {
        setTransparentForImageView(this, null)
        statusBarLightMode(this)
        super.onCreate(savedInstanceState)

        initView()
    }

    override fun initDataAndEvent() {

    }

    override fun layoutResId(): Int {
        return R.layout.activity_play_meditation
    }

    override fun getStatusViewOptions(): StatusBarOptions {
        return StatusBarOptions(true, false)
    }

    private fun initView() {

        mMediaPlayer = MediaPlayerManager.getInstance(this).mediaPlayer

        MediaPlayerManager.getInstance(this).path = path

        val currentPosition = mMediaPlayer?.currentPosition
        duration = mMediaPlayer?.duration?:0

        if (currentPosition!=null){
            exo_position.text = MediaPlayerTimeUtil.calculateTime(currentPosition/1000)
        }
        if (duration!=null){
            exo_duration.text = MediaPlayerTimeUtil.calculateTime(duration/1000)
        }

        Glide.with(this)
            .load(bgUrl)
            .into(iv_bg)

        iv_close.setOnClickListener {
            if (quitDialog == null) {
                quitDialog = QuitMeditationDialog.newInstance()
            }
            if (quitDialog != null && quitDialog?.isAdded == false) {
                quitDialog?.setListener(object : QuitMeditationDialog.ClickListener {
                    override fun quit() {
                        ToastHelper.show("结束练习")
                        finish()
                    }
                })
                quitDialog?.show(supportFragmentManager, QuitMeditationDialog.TAG)
            }
        }

        iv_back.setOnClickListener {
            finish()
        }

        iv_share.setOnClickListener {
            if (shareDialog == null) {
                shareDialog = ShareMeditationDialog
                    .newInstance(
                        shareImageUrl = bgUrl,
                        shareContent = "老铁，我是你要分享的内容"
                    )
            }
            if (shareDialog != null && shareDialog?.isAdded == false) {
                shareDialog?.show(supportFragmentManager, ShareMeditationDialog.TAG)
            }
        }

        tv_title.text = "这是一首简单的冥想BGM"
        tv_content.text = "写着人们心疼的曲折，我想我很快乐，做一个旁观者"

        iv_collect.setOnClickListener {
            collected = !collected
            if (collected) {
                ToastHelper.show("收藏成功！")
                iv_collect.setImageResource(R.drawable.icon_meditation_collected)
            } else {
                ToastHelper.show("取消收藏！")
                iv_collect.setImageResource(R.drawable.icon_play_meditation_collect)
            }

        }
        iv_time_off.setOnClickListener {
            ToastHelper.show("设置定时关闭！")
        }

        exo_play.setOnClickListener {
            if (isPlaying) {
                MediaPlayerManager.getInstance(this).pause()
            } else {
                val duration = mMediaPlayer?.duration

                if (MediaPlayerManager.getInstance(this).path.isNullOrBlank()) {
                    MediaPlayerManager.getInstance(this).path = path

                } else {
                    MediaPlayerManager.getInstance(this).play()
                }
                if (duration != null) {
                    seekbar_play_progress.max = duration
                }
                mTimer.schedule(object :TimerTask(){
                    override fun run() {
                        if (!isSeekbarChanging){
                            seekbar_play_progress.progress = mMediaPlayer?.currentPosition?:0
                        }
                    }
                },0,50)

            }
            isPlaying = !isPlaying
            if (isPlaying) {
                exo_play.setImageResource(R.drawable.icon_pause_play)
            } else {
                exo_play.setImageResource(R.drawable.icon_pause_meditation)
            }

        }

        exo_prev.setOnClickListener {
            MediaPlayerManager.getInstance(this).setNewPath(path)
            isPlaying = if (mMediaPlayer?.isPlaying == true) {
                exo_play.setImageResource(R.drawable.icon_pause_play)
                if (duration != null) {
                    seekbar_play_progress.max = duration
                }
                mTimer.schedule(object :TimerTask(){
                    override fun run() {
                        seekbar_play_progress.progress = mMediaPlayer?.currentPosition?:0
                    }
                },0,50)
                true
            } else {
                exo_play.setImageResource(R.drawable.icon_pause_meditation)
                false
            }
        }

        exo_next.setOnClickListener {
            MediaPlayerManager.getInstance(this).setNewPath(path)
            isPlaying = if (mMediaPlayer?.isPlaying == true) {
                exo_play.setImageResource(R.drawable.icon_pause_play)
                if (duration != null) {
                    seekbar_play_progress.max = duration
                }
                mTimer.schedule(object :TimerTask(){
                    override fun run() {
                        if (!isSeekbarChanging){
                            seekbar_play_progress.progress = mMediaPlayer?.currentPosition?:0
                        }
                    }
                },0,50)
                true
            } else {
                exo_play.setImageResource(R.drawable.icon_pause_meditation)
                false
            }
        }

        exo_rew.setOnClickListener {
            if (mMediaPlayer!=null){
                val currentPosition = mMediaPlayer!!.currentPosition
                val seekPosition = 0.coerceAtLeast(currentPosition - 15000)
                mMediaPlayer!!.seekTo(seekPosition)
            }
        }

        exo_ffwd.setOnClickListener {
            if (mMediaPlayer!=null){
                val currentPosition = mMediaPlayer!!.currentPosition
                val seekPosition = duration.coerceAtMost(currentPosition + 15000)
                mMediaPlayer!!.seekTo(seekPosition)
            }
        }

        seekbar_play_progress.setOnSeekBarChangeListener(object :SeekBar.OnSeekBarChangeListener{
            override fun onProgressChanged(seekBar: SeekBar?, progress: Int, fromUser: Boolean) {
                if (mMediaPlayer!=null){
                    val totalDuration = mMediaPlayer!!.duration / 1000
                    val position = mMediaPlayer!!.currentPosition
                    exo_position.text = MediaPlayerTimeUtil.calculateTime(position/1000)
                    exo_duration.text = MediaPlayerTimeUtil.calculateTime(totalDuration)
                }

            }

            override fun onStartTrackingTouch(seekBar: SeekBar?) {
                isSeekbarChanging = true
            }

            override fun onStopTrackingTouch(seekBar: SeekBar?) {
                isSeekbarChanging = false
                seekBar?.progress?.let {
                    MediaPlayerManager.getInstance(this@PlayMeditationActivity).seekTo(
                        it
                    )
                    if (mMediaPlayer!=null){
                        exo_position.text = MediaPlayerTimeUtil.calculateTime(
                            mMediaPlayer!!.currentPosition/1000
                        )
                    }

                }
            }

        })

        mMediaPlayer?.setOnCompletionListener {
            isPlaying = if (it.isPlaying) {
                exo_play.setImageResource(R.drawable.icon_pause_play)
                true
            } else {
                exo_play.setImageResource(R.drawable.icon_pause_meditation)
                false
            }
        }

    }


    override fun onDestroy() {
        super.onDestroy()
        mTimer.cancel()
        mMediaPlayer?.stop()
        mMediaPlayer?.release()
    }

}